@@ -72,11 +72,12 @@ class CpSysDib():
         stock_code 에 대한 chart return
         """
         date_list = []
+        stock_start_price = []
         stock_last_price = []
         stock_high_price = []
         stock_low_price = []
         
-        fields = [0, 3, 4, 5]
+        fields = [0, 2, 3, 4, 5]
 
         inst_stock_chart = win32com.client.Dispatch("CpSysDib.StockChart")
         
@@ -102,6 +103,9 @@ class CpSysDib():
                     day = str(inst_stock_chart.GetDataValue(0, i))[6:]
                     date = f'{year}-{month}-{day}'
                     date_list.append(date)
+            elif field == 2:
+                for i in range(data_count):
+                    stock_high_price.append(inst_stock_chart.GetDataValue(0, i))
             elif field == 3:
                 for i in range(data_count):
                     stock_high_price.append(inst_stock_chart.GetDataValue(0, i))
